@@ -1,15 +1,14 @@
 from arkitekt.apps.fakts import FaktsApp
-from herre.grants.fakts import FaktsGrant
 from herre.herre import Herre
 from pydantic import Field
 
 
 class ArkitektHerre(Herre):
-    grant: FaktsGrant = Field(default_factory=lambda: FaktsGrant())
+    pass
 
 
 
 class HerreApp(FaktsApp):
     herre: ArkitektHerre = Field(default_factory=ArkitektHerre)
-    """The fakts layer that is used for configuration
+    """The fakts layer thats is used for configuration
     """
