@@ -1,4 +1,5 @@
 from arkitekt.apps import Arkitekt
+from arkitekt.apps.rekuest import ArkitektRekuest, ArkitektAgent
 from fakts.grants.remote.device_code import DeviceCodeGrant
 from fakts.fakts import Fakts
 from fakts.grants.remote.static import StaticGrant
@@ -6,7 +7,7 @@ from fakts.grants import CacheGrant
 from herre.grants import CacheGrant as HerreCacheGrant
 from herre.grants.oauth2.refresh import RefreshGrant
 from herre.grants.fakts import FaktsGrant
-from fakts.discovery import StaticDiscovery
+from fakts.discovery.well_known import WellKnownDiscovery
 from herre import Herre
 import logging
 from koil.composition import PedanticKoil
@@ -15,8 +16,15 @@ from .utils import create_arkitekt_folder
 
 
 def easy(
-    identifier: str, version: str = "latest", url: str = "http://localhost:8000/f/", headless: bool = False, allow_sync_in_async: bool = True, log_level: str = "ERROR",
-token: str = None) -> Arkitekt:
+    identifier: str,
+    version: str = "latest",
+    url: str = "http://localhost:8000",
+    headless: bool = False,
+    allow_sync_in_async: bool = True,
+    log_level: str = "ERROR",
+    token: str = None,
+    instance_id: str = "main",
+) -> Arkitekt:
     """Easy app creation
 
     A simple way to create an Arkitekt app with a device code grant
@@ -33,7 +41,6 @@ token: str = None) -> Arkitekt:
     Returns:
         Arkitekt: _description_
     """
-
     url = os.getenv("FAKTS_URL", url)
     token = os.getenv("FAKTS_TOKEN", token)
 
@@ -46,9 +53,9 @@ token: str = None) -> Arkitekt:
     except ImportError:
         logging.basicConfig(level=log_level)
 
-
     return Arkitekt(
-        title=identifier,
+        identifier=identifier,
+        version=version,
         koil=PedanticKoil(sync_in_async=allow_sync_in_async),
         fakts=Fakts(
             grant=CacheGrant(
@@ -58,7 +65,9 @@ token: str = None) -> Arkitekt:
                     identifier=identifier,
                     version=version,
                     open_browser=not headless,
-                    discovery=StaticDiscovery(base_url=url),
+                    discovery=WellKnownDiscovery(
+                                url=url,
+                                auto_protocols=["https", "http"]),
                 ),
             )
         ),
@@ -69,11 +78,35 @@ token: str = None) -> Arkitekt:
                 grant=RefreshGrant(grant=FaktsGrant()),
             ),
         ),
+        rekuest=ArkitektRekuest(
+            agent=ArkitektAgent(
+                instance_id=instance_id,
+            )
+        ),
     )
 
+
+def jupy(
+    identifier: str,
+    version: str = "latest",
+    url: str = "http://localhost:8000/f/",
+    headless: bool = False,
+) -> Arkitekt:
+
+    app = easy(
+        identifier, version, url, headless, allow_sync_in_async=True, log_level="ERROR"
+    )
+    app.enter()
+    return app
+
+
 def port(
-    identifier: str, version: str = "latest", url: str = "http://localhost:8000/f/",  log_level: str = "ERROR",
-token: str = None) -> Arkitekt:
+    identifier: str,
+    version: str = "latest",
+    url: str = "http://lok:8000",
+    log_level: str = "ERROR",
+    token: str = None,
+) -> Arkitekt:
     """Easy port creation
 
     A simple way to create an Arkitekt app with a device code grant
@@ -82,7 +115,7 @@ token: str = None) -> Arkitekt:
 
     Args:
         identifier (str): The apps identifier
-        version (str, optional): The apps verion. Defaults to "latest".
+        version (str, optiosnal): The apps verion. Defaults to "latest".
         url (_type_, optional): The app configuration url. Defaults to "http://localhost:8000/f/".
         headless (bool, optional): Do not open a browser window. Defaults to False.
         allow_sync_in_async (bool, optional): Should we allow the creation of a sync interface in an async loop (necessary for a sync interface in jupyter). Defaults to True.
@@ -109,14 +142,14 @@ token: str = None) -> Arkitekt:
     except ImportError:
         logging.basicConfig(level=log_level)
 
-
     return Arkitekt(
-        title=identifier,
+        identifier=identifier,
+        version=version,
         fakts=Fakts(
             grant=CacheGrant(
                 cache_file=f".arkitekt/cache/{identifier}-{version}_cache.json",
                 hash=f"{identifier}-{version}-{url}",
-                grant=StaticGrant(token=token, discovery=StaticDiscovery(base_url=url)),
+                grant=StaticGrant(token=token, discovery=WellKnownDiscovery(url=url)),
             )
         ),
         herre=Herre(
@@ -138,10 +171,11 @@ def qt(identifier: str, version: str, parent) -> Arkitekt:
 
     from koil.composition.qt import QtPedanticKoil
 
-
     create_arkitekt_folder(with_cache=True)
 
     return Arkitekt(
+        identifier=identifier,
+        version=version,
         koil=QtPedanticKoil(parent=parent),
         fakts=Fakts(
             grant=CacheGrant(
@@ -149,7 +183,6 @@ def qt(identifier: str, version: str, parent) -> Arkitekt:
                 grant=DeviceCodeGrant(
                     identifier=identifier,
                     version=version,
-
                 ),
             )
         ),
@@ -163,7 +196,14 @@ def qt(identifier: str, version: str, parent) -> Arkitekt:
     )
 
 
-def publicqt(identifier: str, version: str = "latest",  parent = None) -> Arkitekt:
+def publicqt(
+    identifier: str,
+    version: str = "latest",
+    parent=None,
+    beacon_widget=None,
+    login_widget=None,
+    force_herre_grant = None
+) -> Arkitekt:
     """Public QtApp creation
 
     A simple way to create an Arkitekt app with a public grant (allowing users to sign
@@ -179,31 +219,38 @@ def publicqt(identifier: str, version: str = "latest",  parent = None) -> Arkite
         Arkitekt: The Arkitekt app
     """
 
-    from koil.composition.qt import QtPedanticKoil
-    from herre.grants.fakts.fakts_login_screen import FaktsQtLoginScreen, LoginWidget
+    from herre.grants.fakts.fakts_login_screen import FaktsQtLoginScreen
+    from herre.grants.qt.login_screen import LoginWidget
     from fakts.grants.remote.retrieve import RetrieveGrant
-    from fakts.discovery.qt.selectable_beacon import SelectBeaconWidget, QtSelectableDiscovery
-
+    from fakts.discovery.qt.selectable_beacon import (
+        SelectBeaconWidget,
+        QtSelectableDiscovery,
+    )
 
     create_arkitekt_folder(with_cache=True)
 
-    x = SelectBeaconWidget(parent=parent)
-
-    loginWindow = LoginWidget(identifier, version, parent=parent)
+    beacon_widget = beacon_widget or SelectBeaconWidget(parent=parent)
 
+    login_widget = login_widget or LoginWidget(identifier, version, parent=parent)
+    f = FaktsGrant(grant_class=force_herre_grant)
+    print(f)
     app = Arkitekt(
+        identifier=identifier,
+        version=version,
         fakts=Fakts(
             grant=CacheGrant(
-                skip_cache=True,
                 cache_file=f".arkitekt/cache/{identifier}-{version}_fakts_cache.json",
                 grant=RetrieveGrant(
-                            identifier=identifier,
-                            version=version,
-                            redirect_uri="http://localhost:6767",
-                            discovery=QtSelectableDiscovery(
-                                    widget=x,
-                                ),
-                        ),
+                    identifier=identifier,
+                    version=version,
+                    redirect_uri="http://localhost:6767",
+                    discovery=QtSelectableDiscovery(
+                        widget=beacon_widget,
+                        allow_appending_slash=True,
+                        auto_protocols=["http", "https"],
+
+                    ),
+                ),
             ),
             assert_groups={"mikro", "rekuest"},
         ),
@@ -213,9 +260,9 @@ def publicqt(identifier: str, version: str = "latest",  parent = None) -> Arkite
                 hash=f"{identifier}-{version}",
                 skip_cache=True,
                 grant=FaktsQtLoginScreen(
-                    widget=loginWindow,
+                    widget=login_widget,
                     auto_login=True,
-                    grant=RefreshGrant(grant=FaktsGrant()),
+                    grant=RefreshGrant(grant=f),
                 ),
             ),
         ),
@@ -225,7 +272,7 @@ def publicqt(identifier: str, version: str = "latest",  parent = None) -> Arkite
 
 
 def flussi(
-    identifier: str, version: str = "latest", url: str = "http://localhost:8000/f/"
+    identifier: str, version: str = "latest", url: str = "http://localhost:8000"
 ):
     """
     A simple way to create an Arkitekt app with a device code grant
@@ -235,10 +282,11 @@ def flussi(
 
     from arkitekt.apps.fluss import ConnectedFluss
 
-
     create_arkitekt_folder(with_cache=True)
 
     return ConnectedFluss(
+        identifier=identifier,
+        version=version,
         fakts=Fakts(
             grant=CacheGrant(
                 cache_file=f".arkitekt/cache/{identifier}-{version}_cache.json",
@@ -246,7 +294,7 @@ def flussi(
                 grant=DeviceCodeGrant(
                     identifier=identifier,
                     version=version,
-                    discovery=StaticDiscovery(base_url=url),
+                    discovery=WellKnownDiscovery(url=url),
                 ),
             )
         ),
