@@ -1,11 +1,8 @@
 from importlib import import_module
-from rekuest.structures.default import get_default_structure_registry
-from rekuest.definition.registry import get_default_definition_registry
 from arkitekt.utils import create_arkitekt_folder
 from pydantic import BaseModel, Field
-from rekuest.api.schema import DefinitionInput
 import os
-from typing import List, Union, Optional
+from typing import List, Optional
 import yaml
 import json
 import datetime
@@ -16,10 +13,11 @@ def import_deployer(builder):
     function = getattr(module, function_name)
     return function
 
-def generate_definitions(module_path: str = "hu") -> List[DefinitionInput]:
+def generate_definitions(module_path: str = "hu"):
+    from rekuest.definition.registry import get_default_definition_registry
 
-    module_path = f"hu"
-    module = import_module(module_path)
+    module_path = "hu"
+    import_module(module_path)
 
     reg = get_default_definition_registry()
     return list(reg.definitions.keys())
@@ -36,7 +34,7 @@ class Manifest(BaseModel):
 
 def load_manifest() -> Optional[Manifest]:
     path = create_arkitekt_folder()
-    config_file = os.path.join(path, f"manifest.yaml")
+    config_file = os.path.join(path, "manifest.yaml")
     if os.path.exists(config_file):
         with open(config_file, "r") as file:
             manifest = yaml.safe_load(file)
@@ -46,10 +44,10 @@ def load_manifest() -> Optional[Manifest]:
 def write_manifest(manifest: Manifest):
    
     path = create_arkitekt_folder()
-    config_file = os.path.join(path, f"manifest.yaml")
+    config_file = os.path.join(path, "manifest.yaml")
 
     with open(config_file, "w") as file:
-        documents = yaml.safe_dump(json.loads(manifest.json(exclude_none=True, exclude_unset=True)), file, sort_keys=True)
+        yaml.safe_dump(json.loads(manifest.json(exclude_none=True, exclude_unset=True)), file, sort_keys=True)
 
 
 
