@@ -8,6 +8,7 @@ import os
 import sys
 from .utils import build_relative_dir
 import shutil
+import getpass
 from .ui import construct_leaking_group
 
 console = Console()
@@ -414,7 +415,7 @@ def init(identifier, version, author, entrypoint, builder, scopes, template):
 
 
     manifest = Manifest(
-            author=author or click.prompt(" Your name:", default=getattr(oldmanifest, "author", "john doe")),
+            author=author or click.prompt(" Your name:", default=getattr(oldmanifest, "author", getpass.getuser())),
             identifier=identifier or click.prompt(" Your apps name: ", default=getattr(oldmanifest, "identifier", os.path.basename(os.getcwd()))),
             version=version or click.prompt(" The current version of this app: ", default=getattr(oldmanifest, "version", "dev")),
             entrypoint=entrypoint or click.prompt(" Where should we search for the entrypoint?", default=getattr(oldmanifest, "entrypoint", "app")),
